[−][src]Struct pancurses::Attributes
Methods
impl Attributes[src]
impl Attributespub fn new() -> Attributes[src]
pub fn new() -> Attributespub fn is_alternative_char_set(&self) -> bool[src]
pub fn is_alternative_char_set(&self) -> boolpub fn set_alternative_char_set(&mut self, enabled: bool)[src]
pub fn set_alternative_char_set(&mut self, enabled: bool)pub fn is_bold(&self) -> bool[src]
pub fn is_bold(&self) -> boolpub fn set_bold(&mut self, enabled: bool)[src]
pub fn set_bold(&mut self, enabled: bool)pub fn is_blink(&self) -> bool[src]
pub fn is_blink(&self) -> boolpub fn set_blink(&mut self, enabled: bool)[src]
pub fn set_blink(&mut self, enabled: bool)pub fn is_char_text(&self) -> bool[src]
pub fn is_char_text(&self) -> boolpub fn set_char_text(&mut self, enabled: bool)[src]
pub fn set_char_text(&mut self, enabled: bool)pub fn is_dim(&self) -> bool[src]
pub fn is_dim(&self) -> boolpub fn set_dim(&mut self, enabled: bool)[src]
pub fn set_dim(&mut self, enabled: bool)pub fn is_leftline(&self) -> bool[src]
pub fn is_leftline(&self) -> boolpub fn set_leftline(&mut self, enabled: bool)[src]
pub fn set_leftline(&mut self, enabled: bool)pub fn is_invisible(&self) -> bool[src]
pub fn is_invisible(&self) -> boolpub fn set_invisible(&mut self, enabled: bool)[src]
pub fn set_invisible(&mut self, enabled: bool)pub fn is_italic(&self) -> bool[src]
pub fn is_italic(&self) -> boolpub fn set_italic(&mut self, enabled: bool)[src]
pub fn set_italic(&mut self, enabled: bool)pub fn is_normal(&self) -> bool[src]
pub fn is_normal(&self) -> boolpub fn set_normal(&mut self)[src]
pub fn set_normal(&mut self)pub fn is_overline(&self) -> bool[src]
pub fn is_overline(&self) -> boolpub fn set_overline(&mut self, enabled: bool)[src]
pub fn set_overline(&mut self, enabled: bool)pub fn is_reverse(&self) -> bool[src]
pub fn is_reverse(&self) -> boolpub fn set_reverse(&mut self, enabled: bool)[src]
pub fn set_reverse(&mut self, enabled: bool)pub fn is_rightline(&self) -> bool[src]
pub fn is_rightline(&self) -> boolpub fn set_rightline(&mut self, enabled: bool)[src]
pub fn set_rightline(&mut self, enabled: bool)pub fn is_strikeout(&self) -> bool[src]
pub fn is_strikeout(&self) -> boolpub fn set_strikeout(&mut self, enabled: bool)[src]
pub fn set_strikeout(&mut self, enabled: bool)pub fn is_underline(&self) -> bool[src]
pub fn is_underline(&self) -> boolpub fn set_underline(&mut self, enabled: bool)[src]
pub fn set_underline(&mut self, enabled: bool)pub fn color_pair(&self) -> ColorPair[src]
pub fn color_pair(&self) -> ColorPairpub fn set_color_pair(&mut self, color_pair: ColorPair)[src]
pub fn set_color_pair(&mut self, color_pair: ColorPair)Trait Implementations
impl Copy for Attributes[src]
impl Copy for Attributesimpl Clone for Attributes[src]
impl Clone for Attributesfn clone(&self) -> Attributes[src]
fn clone(&self) -> AttributesReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Debug for Attributes[src]
impl Debug for Attributesfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Attributes[src]
impl PartialEq for Attributesfn eq(&self, other: &Attributes) -> bool[src]
fn eq(&self, other: &Attributes) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Attributes) -> bool[src]
fn ne(&self, other: &Attributes) -> boolThis method tests for !=.
impl Eq for Attributes[src]
impl Eq for Attributesimpl Hash for Attributes[src]
impl Hash for Attributesfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl BitOr<Attribute> for Attributes[src]
impl BitOr<Attribute> for AttributesImplement the | operator for adding an Attribute to Attributes
Example
use pancurses::{Attribute, Attributes}; let mut attributes = Attributes::new(); assert!(!attributes.is_bold()); attributes = attributes | Attribute::Bold; assert!(attributes.is_bold());
type Output = Attributes
The resulting type after applying the | operator.
fn bitor(self, rhs: Attribute) -> Attributes[src]
fn bitor(self, rhs: Attribute) -> AttributesPerforms the | operation.
impl BitXor<Attribute> for Attributes[src]
impl BitXor<Attribute> for AttributesImplement the ^ operator for disabling an Attribute from Attributes
Example
use pancurses::{Attribute, Attributes}; let mut attributes = Attributes::from(Attribute::Bold); assert!(attributes.is_bold()); attributes = attributes ^ Attribute::Bold; assert!(!attributes.is_bold());
type Output = Attributes
The resulting type after applying the ^ operator.
fn bitxor(self, rhs: Attribute) -> Attributes[src]
fn bitxor(self, rhs: Attribute) -> AttributesPerforms the ^ operation.
impl BitOr for Attributes[src]
impl BitOr for AttributesImplement the | operator for adding Attributes to Attributes
Example
use pancurses::{Attribute, Attributes}; let mut attributes = Attributes::new() | Attribute::Bold; let other = Attributes::new() | Attribute::Reverse; attributes = attributes | other; assert!(attributes.is_bold()); assert!(attributes.is_reverse()); assert!(!attributes.is_italic());
type Output = Attributes
The resulting type after applying the | operator.
fn bitor(self, rhs: Attributes) -> Attributes[src]
fn bitor(self, rhs: Attributes) -> AttributesPerforms the | operation.
impl BitXor for Attributes[src]
impl BitXor for AttributesImplement the ^ operator for removing Attributes from Attributes
Example
use pancurses::{Attribute, Attributes}; let mut attributes = Attributes::new() | Attribute::Blink | Attribute::Bold; let other = Attributes::new() | Attribute::Reverse | Attribute::Bold; attributes = attributes ^ other; assert!(!attributes.is_bold()); assert!(attributes.is_reverse()); assert!(attributes.is_blink());
type Output = Attributes
The resulting type after applying the ^ operator.
fn bitxor(self, rhs: Attributes) -> Attributes[src]
fn bitxor(self, rhs: Attributes) -> AttributesPerforms the ^ operation.
impl Default for Attributes[src]
impl Default for AttributesImplement Default for Attributes
Example
use pancurses::Attributes; let attributes: Attributes = Default::default(); assert_eq!(attributes, Attributes::new());
impl From<Attribute> for Attributes[src]
impl From<Attribute> for Attributesfn from(attribute: Attribute) -> Attributes[src]
fn from(attribute: Attribute) -> AttributesPerforms the conversion.
impl From<Attributes> for chtype[src]
impl From<Attributes> for chtypefn from(attributes: Attributes) -> chtype[src]
fn from(attributes: Attributes) -> chtypePerforms the conversion.
impl BitOr<ColorPair> for Attributes[src]
impl BitOr<ColorPair> for AttributesImplement the | operator for setting a color pair on an Attributes object
Example
use pancurses::{Attribute, Attributes}; use pancurses::colorpair::ColorPair; let mut attributes = Attributes::new(); assert!(attributes.color_pair().0 == 0); attributes = attributes | ColorPair(1); assert!(attributes.color_pair().0 == 1);
type Output = Attributes
The resulting type after applying the | operator.
fn bitor(self, rhs: ColorPair) -> Attributes[src]
fn bitor(self, rhs: ColorPair) -> AttributesPerforms the | operation.